@@ -11,8 +11,15 @@ class GetInstanceFieldHandler(AbstractCommandHandler):
             if len(command.payload) != self._required_parameters_count:
                 raise Exception("GetInstanceFieldHandler parameters mismatch!")
             clazz = command.payload[0]
-            value = getattr(clazz, command.payload[1])
-            return value
+            field = command.payload[1]
+            try:
+                return getattr(clazz, field)
+            except AttributeError:
+                fields = [field for field in dir(clazz) if not callable(getattr(clazz, field))]
+                message = "Field {} not found in class {}. Available fields:\n".format(field, clazz.__name__)
+                for field in fields:
+                    message += "{}\n".format(field)
+                raise AttributeError(message)
         except Exception as e:
             exc_type, exc_value = type(e), e
             new_exc = exc_type(exc_value).with_traceback(e.__traceback__)
