@@ -10,7 +10,8 @@ our @EXPORT = qw(get_connection_type);
 
 my %connection_type = (
     'InMemory'       => 0,
-    'Tcp'    => 1
+    'Tcp'    => 1,
+    'WithConfig' => 2,
 );
 
 sub get_connection_type {
